API Reference
=============

.. toctree::
   :maxdepth: 1

   api/fix1d.rst
   api/fix1dmw.rst
   api/fix2d.rst
   api/var1d.rst
   api/var1dmw.rst
   api/var2d.rst
   api/histogram.rst
   api/histogram2d.rst
   api/force_omp.rst
   api/disable_omp.rst
